/*
 **
 ** MainActivity.java - top class of the SensorServer
 **
 ** Copyright (C) 2019 Elphel, Inc.
 **
 ** -----------------------------------------------------------------------------**
 **
 **  MainActivity.java is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  This program is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ** -----------------------------------------------------------------------------**
 **
 */

package com.elphel.sensorserver;

import java.net.InetAddress;
import java.net.UnknownHostException;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;

import android.app.Activity;
import android.net.wifi.WifiInfo;
import android.net.wifi.WifiManager;
import android.os.Bundle;
import android.util.Log;
import android.util.TypedValue;
import android.widget.TextView;

public class MainActivity extends Activity {
    private static String  TAG = "ServerSocket-MAIN";
	private  Server   server = null;
	private  TextView text;
	private SensorsUpdate sensorsUpdate = new SensorsUpdate(this);
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);


		sensorsUpdate.start();
		server = new Server(this, sensorsUpdate);
		setContentView(R.layout.activity_main);

		server.start();
	}

	@Override
	protected void onPause() {
		super.onPause();

		sensorsUpdate.pause();

		if (server != null) {
			server.stop();
			server = null;
		}
	}
	@Override
	protected void onResume() {
		super.onResume();

		String ip = "???";
		try {
			WifiManager wifiMgr = (WifiManager) getSystemService(WIFI_SERVICE);
			WifiInfo wifiInfo = wifiMgr.getConnectionInfo();
			Log.i(TAG,"wifiInfo = " + wifiInfo.toString());
			int ipInt = wifiInfo.getIpAddress();
			Log.i(TAG,"wifiIP = " + String.format("0x%x", ipInt));
			ip = InetAddress.getByAddress(
					ByteBuffer.allocate(4).order(ByteOrder.LITTLE_ENDIAN).putInt(ipInt).array())
					.getHostAddress();
		} catch (UnknownHostException e) {
			  Log.d(TAG,"UnknownHostException:" + e.getMessage());
		} catch (Exception e1) {
			  Log.d(TAG,"Exception:" + e1.getMessage());
		}
		text = new TextView(this);

		text.setText("Server WiFi address/port:\n"+ip+":"+server.getPort());
		text.setTextSize(TypedValue.COMPLEX_UNIT_SP, 30.0f);

		setContentView(text);

		sensorsUpdate.resume();

		if (server == null) {
			server = new Server(this, sensorsUpdate);
			server.start();
		}
	}

}

